Crate mermer_rs

Crate mermer_rs 

Structs

Chromosome
A distinct chromosome in the genome.

Functions

do_the_search
identify_matches
make_tables
Return the “Match Mask Array” for a search.
read_fasta
Return the preprocessed genome, a list of exceptions, and a list of chromosomes for the genome specified in a .fasta file.